#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 persistent-mysql
version:              2.13.1.5
visibility:           public
id:                   persistent-mysql-2.13.1.5-4EOUjZIsQ1w9sg6Nwuje1K
key:                  persistent-mysql-2.13.1.5-4EOUjZIsQ1w9sg6Nwuje1K
license:              MIT
maintainer:           Felipe Lessa <felipe.lessa@gmail.com>
author:               Felipe Lessa <felipe.lessa@gmail.com>, Michael Snoyman
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:
    Backend for the persistent library using MySQL database server.

description:
    This package contains a backend for persistent using the
    MySQL database server.  Internally it uses the @mysql-simple@
    and @mysql@ packages in order to access the database.

    This package supports only MySQL 5.1 and above.  However, it
    has been tested only on MySQL 5.5.
    Only the InnoDB storage engine is officially supported.

    Known problems:

    * This package does not support statements inside other
    statements.

category:             Database, Yesod
abi:                  b378e78e2d94617b2b5b81b68187f6a1
exposed:              True
exposed-modules:      Database.Persist.MySQL
import-dirs:          /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/persistent-mysql-2.13.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-persistent-mysql
hs-libraries:         HSpersistent-mysql-2.13.1.5-4EOUjZIsQ1w9sg6Nwuje1K
depends:
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ base-4.18.2.1
    blaze-builder-0.4.4.1-LpEq21LNRHq8DXqqJhoUXc bytestring-0.11.5.3
    conduit-1.3.6.1-bHMGfLNlzWFeFHMt1zPL0 containers-0.6.7
    monad-logger-0.3.42-EMre5GSol0TLeYULj6MTtt
    mysql-0.2.1-1K1tBYSEd2oHmz7U4jm940
    mysql-simple-0.4.9-Ce2JPaP1rjIH5M5GdK7Ji6
    persistent-2.14.5.2-1FV0PJBgAYf4FZoE6afIlJ
    resource-pool-0.2.3.2-DtsrnNeBIIv7mY3xjP0Wqu
    resourcet-1.2.6-BTixKgkFAZ7Fh4PNhKyioS text-2.0.2
    transformers-0.6.1.0 unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:
    /usr/share/doc/haskell-persistent-mysql/html/persistent-mysql.haddock

haddock-html:         /usr/share/doc/haskell-persistent-mysql/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

